@@ -1,18 +1,17 @@
-# Project documentation for tigger
-# 
-# @author     Daniel Gadala-Maria
-# @copyright  Copyright 2016 Kleinstein Lab, Yale University. All rights reserved
-# @license    Creative Commons Attribution-NonCommercial-ShareAlike 4.0 Unported
+#' @keywords internal
+#' @aliases tigger-package
+"_PACKAGE"
 
+# Project documentation for tigger
 
 #' tigger
-#' 
+#'
 #' Here we provide a \strong{T}ool for \strong{I}mmuno\strong{g}lobulin
-#' \strong{G}enotype \strong{E}lucidation via \strong{R}ep-Seq (TIgGER). 
-#' TIgGER inferrs the set of Ig alleles carried by an
+#' \strong{G}enotype \strong{E}lucidation via \strong{R}ep-Seq (TIgGER).
+#' TIgGER infers the set of Ig alleles carried by an
 #' individual (including any novel alleles) and then uses this set of alleles to
 #' correct the initial assignments given to sample sequences by existing tools.
-#' 
+#'
 #' @details
 #' Immunoglobulin repertoire sequencing (AIRR-Seq, Rep-Seq) data is currently the
 #' subject of much study. A key step in analyzing these data involves assigning
@@ -22,7 +21,7 @@
 #' step will fail. Additionally, this alignment has an associated error rate of
 #' ~5%, notably among sequences carrying a large number of somatic
 #' mutations. The purpose of TIgGER is to address these issues.
-#' 
+#'
 #' @section  Allele detection and genotyping:
 #' \itemize{
 #'   \item  \link{findNovelAlleles}:       Detect novel alleles.
@@ -32,10 +31,10 @@
 #'   \item  \link{plotGenotype}:           A colorful genotype visualization.
 #'   \item  \link{genotypeFasta}:          Convert a genotype to sequences.
 #'   \item  \link{reassignAlleles}:        Correct allele calls.
-#'   \item  \link{generateEvidence}:       Generate evidence for the genotype and 
-#'                                         allele detection inferrence.
+#'   \item  \link{generateEvidence}:       Generate evidence for the genotype and
+#'                                         allele detection inference.
 #' }
-#' 
+#'
 #' @section  Mutation handling:
 #' \itemize{
 #'   \item  \link{getMutatedPositions}:      Find mutation locations.
@@ -45,7 +44,7 @@
 #'                                           mutation count.
 #'   \item  \link{insertPolymorphisms}:      Insert SNPs into a sequence.
 #' }
-#' 
+#'
 #' @section  Input, output and formatting:
 #' \itemize{
 #'   \item  \link{readIgFasta}:        Read a fasta file of Ig sequences.
@@ -53,16 +52,15 @@
 #'   \item  \link{sortAlleles}:        Sort allele names intelligently.
 #'   \item  \link{cleanSeqs}:          Standardize sequence format.
 #' }
-#' 
+#'
 #' @name        tigger
-#' @docType     package
 #' @references
 #' \enumerate{
-#'   \item Gadala-Maria, et al. (2015) Automated analysis of high-throughput B cell 
-#'         sequencing data reveals a high frequency of novel immunoglobulin V gene 
+#'   \item Gadala-Maria, et al. (2015) Automated analysis of high-throughput B cell
+#'         sequencing data reveals a high frequency of novel immunoglobulin V gene
 #'         segment alleles. PNAS. 112(8):E862-70.
 #' }
-#' 
+#'
 #' @import      ggplot2
 #' @importFrom  alakazam    getAllele getGene getFamily translateDNA DNA_COLORS checkColumns
 #' @importFrom  doParallel  registerDoParallel
@@ -72,9 +70,8 @@
 #'                          bind_cols bind_rows combine inner_join
 #'                          filter select arrange
 #'                          group_by ungroup
-#'                          mutate transmute
-#'                          rename summarise
-#'                          slice
+#'                          mutate pull rename slice
+#'                          summarise transmute
 #' @importFrom  foreach     foreach %dopar% registerDoSEQ
 #' @importFrom  graphics    plot
 #' @importFrom  gridExtra   arrangeGrob
@@ -83,10 +80,17 @@
 #' @importFrom  lazyeval    interp
 #' @importFrom  parallel    clusterEvalQ clusterExport makeCluster stopCluster
 #' @importFrom  rlang       .data := sym syms
-#' @importFrom  shazam      calcObservedMutations
 #' @importFrom  stats       na.omit setNames ecdf sd cor cov median mad
 #'                          confint lm
 #' @importFrom  stringi     stri_length stri_detect_fixed stri_replace_all_regex
 #'                          stri_sub stri_sub<- stri_trans_toupper
 #' @importFrom  tidyr       gather spread unnest
+#' @importFrom  utils       citation
 NULL
+
+# Package loading actions
+.onAttach <- function(libname, pkgname) {
+    msg <- citation(pkgname)
+    msg <- paste(c(format(msg, "citation")), collapse = "\n\n")
+    packageStartupMessage(msg)
+}
